"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
const fix_1 = require("./fix");
const scenarios = node_fs_1.default
    .readFileSync(node_path_1.default.join(__dirname, './testcases.txt'), 'utf8')
    .replace(/^#[^\n]*\n/gm, '')
    .trim()
    .split('\n\n')
    .map((pairs) => pairs.split('\n'))
    .map(([source, expected]) => ({ source: source.replace(/█.*/, ''), expected }));
(0, vitest_1.describe)('Unit: fix', async () => {
    (0, vitest_1.it)('closes open strings inside Liquid output', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello`)).to.equal(`{{ 'hello'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello`)).to.equal(`{{ "hello"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello' | append: ' world`)).to.equal(`{{ 'hello' | append: ' world'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello" | append: " world`)).to.equal(`{{ "hello" | append: " world"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello' | replace: 'hello', 'hi`)).to.equal(`{{ 'hello' | replace: 'hello', 'hi'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello" | replace: "hello", "hi`)).to.equal(`{{ "hello" | replace: "hello", "hi"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "don't freak out`)).to.equal(`{{ "don't freak out"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'he said: "no way!`)).to.equal(`{{ 'he said: "no way!'}}`);
    });
    (0, vitest_1.it)('does not close strings inside text blocks', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`<a href="hi">don't freak out<img href`)).to.equal(`<a href="hi">don't freak out<img href>`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a href="hi">a quote "<img href`)).to.equal(`<a href="hi">a quote "<img href>`);
    });
    (0, vitest_1.it)('does not close parens inside text blocks', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`<a>([<b`)).to.equal(`<a>([<b>`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a>])<b`)).to.equal(`<a>])<b>`);
    });
    (0, vitest_1.it)('does not care about brackets inside strings', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`<a attr="([`)).to.equal(`<a attr="([">`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a attr="%}`)).to.equal(`<a attr="%}">`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a attr="}}`)).to.equal(`<a attr="}}">`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "([`)).to.equal(`{{ "(["}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{% echo "([`)).to.equal(`{% echo "(["%}`);
    });
    (0, vitest_1.it)('should panic gracefully', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "}}`)).to.equal(`{{ "}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{% "%}`)).to.equal(`{% "%}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a href=">`)).to.equal(`<a href=">`);
        (0, vitest_1.expect)((0, fix_1.fix)(`<a href="{% echo '>%}`)).to.equal(`<a href="{% echo '>%}">`);
    });
    (0, vitest_1.it)('closes multiline stuff', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`\n{{\n\n  'hello`)).to.equal(`\n{{\n\n  'hello'}}`);
    });
    (0, vitest_1.it)('does not close closed strings inside Liquid output', () => {
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello'`)).to.equal(`{{ 'hello'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello"`)).to.equal(`{{ "hello"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello' | append: ' world`)).to.equal(`{{ 'hello' | append: ' world'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello" | append: " world`)).to.equal(`{{ "hello" | append: " world"}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ 'hello' | replace: 'hello', 'hi'`)).to.equal(`{{ 'hello' | replace: 'hello', 'hi'}}`);
        (0, vitest_1.expect)((0, fix_1.fix)(`{{ "hello" | replace: "hello", "hi"`)).to.equal(`{{ "hello" | replace: "hello", "hi"}}`);
    });
    (0, vitest_1.it)('appends a cursor character as a placeholder for variable lookups (to be used with completion mode parsing)', () => {
        const contexts = [
            `{{ █}}`,
            `{{ a.█}}`,
            `{{ a[█]}}`,
            `{{ a['█']}}`,
            `{{ a.b.█}}`,
            `{% echo █%}`,
            `{% echo a.█%}`,
            `{% echo a['█']%}`,
            `{% assign x = █%}`,
            `{% assign x = a.█%}`,
            `{% assign x = a['█']%}`,
            `{% for a in █%}`,
            `{% for a in b reversed limit: █%}`,
            `{% paginate b by █%}`,
            `{% paginate b by col, window_size: █%}`,
            `{% if █%}`,
            `{% if a > █%}`,
            `{% if a > b or █%}`,
            `{% if a > b or c > █%}`,
            `{% elsif a > █%}`,
            `{% when █%}`,
            `{% when a, █%}`,
            `{% cycle █%}`,
            `{% cycle 'foo', █%}`,
            `{% cycle 'foo': █%}`,
            `{% render 'snip', var: █%}`,
            `{% render 'snip' for █%}`,
            `{% render 'snip' with █%}`,
            `{% for x in (1..█)%}`,
            // `{% paginate █ by 50 %}`,
            `<a-{{ █}}>`,
            `<a data-{{ █}}>`,
            `<a data={{ █}}>`,
            `<a data="{{ █}}">`,
            `<a data='x{{ █}}'>`,
        ];
        for (const context of contexts) {
            (0, vitest_1.expect)((0, fix_1.fix)(context.replace(/█.*$/, ''))).to.equal(context);
        }
    });
    (0, vitest_1.it)('appends a cursor character as a placeholder for html element names (to be used with completion mode parsing)', () => {
        // prettier-ignore
        const contexts = [
            `<█>`,
            `</█>`,
        ];
        for (const context of contexts) {
            (0, vitest_1.expect)((0, fix_1.fix)(context.replace(/█.*$/, ''))).to.equal(context);
        }
    });
    (0, vitest_1.it)('appends a cursor character as a placeholder for html attribute names (to be used with completion mode parsing)', () => {
        // prettier-ignore
        const contexts = [
            `<a █>`,
            `<a attr="value" █>`,
            `<a {% if cond %}█>`,
            `<a {% if cond %}\n█>`,
        ];
        for (const context of contexts) {
            (0, vitest_1.expect)((0, fix_1.fix)(context.replace(/█.*$/, ''))).to.equal(context);
        }
    });
    (0, vitest_1.it)('appends a cursor character as a placeholder for html attribute values (to be used with completion mode parsing)', () => {
        // prettier-ignore
        const contexts = [
            `<a attr="█">`,
            `<a attr='█'>`,
        ];
        for (const context of contexts) {
            (0, vitest_1.expect)((0, fix_1.fix)(context.replace(/█.*$/, ''))).to.equal(context);
        }
    });
    (0, vitest_1.describe)('Case: the rest of the fucking owl', () => {
        (0, vitest_1.it)('fixes templates properly', () => {
            for (const { source, expected } of scenarios) {
                (0, vitest_1.expect)((0, fix_1.fix)(source), source).to.eql(expected);
            }
        });
    });
});
//# sourceMappingURL=fix.spec.js.map