"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const CompletionsProvider_1 = require("../CompletionsProvider");
const docset_1 = require("../../docset");
const common_1 = require("./common");
const allTagNames = [...docset_1.HtmlData.tags].sort(common_1.sortByName).map((x) => x.name);
(0, vitest_1.describe)('Module: HtmlTagCompletionProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new CompletionsProvider_1.CompletionsProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should complete html tag open names', async () => {
        await (0, vitest_1.expect)(provider).to.complete('<█', allTagNames);
        await (0, vitest_1.expect)(provider).to.complete('<h█', allTagNames.filter((x) => x.startsWith('h')));
    });
    (0, vitest_1.it)('should complete void elements with only the void element', async () => {
        await (0, vitest_1.expect)(provider).to.complete('<img█', allTagNames.filter((x) => x === 'img'));
    });
    (0, vitest_1.it)('should complete html tag open names with parent name', async () => {
        await (0, vitest_1.expect)(provider).to.complete('<a><', ['/a'].concat(allTagNames));
    });
    (0, vitest_1.it)('should complete html tag close with the appropriate dangling parent name', async () => {
        await (0, vitest_1.expect)(provider).to.complete('</█', []);
        await (0, vitest_1.expect)(provider).to.complete('<h1></h█', ['h1']);
        await (0, vitest_1.expect)(provider).to.complete('<h></h█', []); // nothing to complete since closed exactly
    });
    (0, vitest_1.it)('should not complete compound html tag names', async () => {
        await (0, vitest_1.expect)(provider).to.complete('<{{ thing }}█', []);
        await (0, vitest_1.expect)(provider).to.complete('<{{ thing }}h█', []);
    });
});
//# sourceMappingURL=HtmlTagCompletionProvider.spec.js.map