"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tags = void 0;
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const CompletionsProvider_1 = require("../CompletionsProvider");
exports.tags = [
    { name: 'render' },
    { name: 'for' },
    { name: 'comment' },
    { name: 'if' },
    { name: 'echo' },
];
(0, vitest_1.describe)('Module: LiquidTagsCompletionProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new CompletionsProvider_1.CompletionsProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => exports.tags,
        });
    });
    (0, vitest_1.it)('should complete Liquid tags', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% comm', ['comment']);
        await (0, vitest_1.expect)(provider).to.complete('{% com', ['comment']);
        await (0, vitest_1.expect)(provider).to.complete('{% re', ['render']);
        await (0, vitest_1.expect)(provider).to.complete('{% ren', ['render']);
        await (0, vitest_1.expect)(provider).to.complete('{% rend', ['render']);
        await (0, vitest_1.expect)(provider).to.complete('{% fo', ['for']);
    });
    (0, vitest_1.it)('should complete end tags with the correct thing', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% comment %} hello there {% end', ['endcomment']);
        await (0, vitest_1.expect)(provider).to.complete('{% if cond %} hello {% else %} then {% end', ['endif']);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %}{% end', ['endfor']);
        await (0, vitest_1.expect)(provider).to.complete('{% javascript %} console.log("hi") {% end', [
            'endjavascript',
        ]);
        await (0, vitest_1.expect)(provider).to.complete('{% form "cart", cart %} ... {% end', ['endform']);
    });
    (0, vitest_1.it)('should offer the proper end tags in context', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% comment %} hello there {% e', ['echo', 'endcomment']);
        await (0, vitest_1.expect)(provider).to.complete('{% if cond %} hello {% else %} then {% e', [
            'echo',
            'endif',
        ]);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %}{% e', ['echo', 'endfor']);
        await (0, vitest_1.expect)(provider).to.complete('{% javascript %} console.log("hi") {% e', [
            'echo',
            'endjavascript',
        ]);
        await (0, vitest_1.expect)(provider).to.complete('{% form "cart", cart %} ... {% e', ['echo', 'endform']);
    });
    (0, vitest_1.it)('should not complete anything if the partial end tag does not match', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% comment %} hello there {% endz', []);
        await (0, vitest_1.expect)(provider).to.complete('{% if cond %} hello {% else %} then {% endz', []);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %}{% endz', []);
        await (0, vitest_1.expect)(provider).to.complete('{% javascript %} console.log("hi") {% endz', []);
        await (0, vitest_1.expect)(provider).to.complete('{% form "cart", cart %} ... {% endz', []);
    });
    (0, vitest_1.it)('should complete empty statements', async () => {
        const allTags = exports.tags.map((x) => x.name).sort();
        await (0, vitest_1.expect)(provider).to.complete('{% ', allTags);
        await (0, vitest_1.expect)(provider).to.complete('{% comment %} hello there {% ', allTags.concat('endcomment'));
        await (0, vitest_1.expect)(provider).to.complete('{% if cond %} hello {% else %} then {% ', allTags.concat('endif'));
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %}{% ', allTags.concat('endfor'));
        await (0, vitest_1.expect)(provider).to.complete('{% javascript %} console.log("hi") {% ', allTags.concat('endjavascript'));
        await (0, vitest_1.expect)(provider).to.complete('{% form "cart", cart %} ... {% ', allTags.concat('endform'));
    });
    (0, vitest_1.it)('should not complete when the cursor position is not on the name', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3)█', []);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) █', []);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %}█', []);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %} hi {% endfor %}█', []);
        await (0, vitest_1.expect)(provider).to.complete('{% for i in (1..3) %} hi {% endfor %}█', []);
        await (0, vitest_1.expect)(provider).to.complete('{% render "snip█', []);
    });
    (0, vitest_1.it)('should complete completed tags', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{% for█ i in (1..3)', ['for']);
        await (0, vitest_1.expect)(provider).to.complete('{% render█ "markup"', ['render']);
    });
});
//# sourceMappingURL=LiquidTagsCompletionProvider.spec.js.map