"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const CompletionsProvider_1 = require("../CompletionsProvider");
(0, vitest_1.describe)('Module: TranslationCompletionProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new CompletionsProvider_1.CompletionsProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [],
        }, async (_) => ({
            general: {
                username_html: '<b>username</b>',
                password: 'password',
                comments: {
                    one: '{{ count }} comment',
                    other: '{{ count }} comments',
                },
            },
        }));
    });
    (0, vitest_1.it)('should complete translations correctly', async () => {
        await (0, vitest_1.expect)(provider).to.complete('{{ "genera', [
            '"general.username_html" | t',
            '"general.password" | t',
            '"general.comments" | t',
        ]);
        await (0, vitest_1.expect)(provider).to.complete('{{ "general.comments', [
            vitest_1.expect.objectContaining({
                documentation: {
                    kind: 'markdown',
                    value: vitest_1.expect.stringMatching(/one(.|\n)*comment(.|\n)*other(.|\n)*comments/m),
                },
            }),
        ]);
        await (0, vitest_1.expect)(provider).to.complete('{{ "general.passwo█" }}', [
            vitest_1.expect.objectContaining({
                label: '"general.password" | t',
                insertText: 'password',
                textEdit: vitest_1.expect.objectContaining({
                    newText: 'general.password" | t',
                }),
            }),
        ]);
    });
});
//# sourceMappingURL=TranslationCompletionProvider.spec.js.map