"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: HtmlAttributeHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should return the hover description of the attribute', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`<a hr█ef="..."></a>`, vitest_1.expect.stringMatching(/##* href/));
        await (0, vitest_1.expect)(provider).to.hover(`<a href█="..."></a>`, vitest_1.expect.stringMatching(/##* href/));
        await (0, vitest_1.expect)(provider).to.hover(`<img src█="...">`, vitest_1.expect.stringMatching(/##* src/));
        await (0, vitest_1.expect)(provider).to.hover(`<img src█='...'>`, vitest_1.expect.stringMatching(/##* src/));
        await (0, vitest_1.expect)(provider).to.hover(`<img src█=...>`, vitest_1.expect.stringMatching(/##* src/));
        await (0, vitest_1.expect)(provider).to.hover(`<img src█>`, vitest_1.expect.stringMatching(/##* src/));
    });
    (0, vitest_1.it)('should return the hover description inside if statements', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{% if cond %}<a hr█ef="..."></a>{% endif %}`, vitest_1.expect.stringMatching(/##* href/));
        await (0, vitest_1.expect)(provider).to.hover(`{% if cond %}{% else %}<a hr█ef="..."></a>{% endif %}`, vitest_1.expect.stringMatching(/##* href/));
    });
    (0, vitest_1.it)('should return nothing if the thing is unknown', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`<a unkn█own></a>`, null);
    });
});
//# sourceMappingURL=HtmlAttributeHoverProvider.spec.js.map