"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.complete = void 0;
const vitest_1 = require("vitest");
const complete = async function (provider, context, expected) {
    const { isNot, equals, utils } = this;
    const completeContext = asCompleteContextObject(context);
    const source = createSourceCode(completeContext);
    const completionParams = createCompletionParams(completeContext);
    provider.documentManager.open(completionParams.textDocument.uri, source, 1);
    const result = await provider.completions(completionParams);
    return {
        pass: result.length === expected.length &&
            expected.every((expectation, i) => equals(result[i], typeof expectation === 'string'
                ? vitest_1.expect.objectContaining({
                    label: expectation,
                })
                : expectation)),
        message: () => `expected complete to${isNot ? ' not' : ''} match value ${utils.printExpected(expected)}\ncontext:\n${context}`,
        actual: result,
        expected: expected,
    };
};
exports.complete = complete;
function asCompleteContextObject(context) {
    if (typeof context === 'string')
        return { source: context, relativePath: 'file.liquid' };
    return context;
}
function createSourceCode(context) {
    const regex = new RegExp('█', 'g');
    return context.source.replace(regex, '');
}
function createCompletionParams(context) {
    const position = createPosition(context.source);
    const textDocument = { uri: `/path/to/${context.relativePath}` };
    return {
        position,
        textDocument,
    };
}
function createPosition(context) {
    const index = context.indexOf('█');
    const lines = context.substring(0, index === -1 ? context.length : index).split('\n');
    const line = lines.length - 1;
    const character = lines[line].length;
    return { line, character };
}
//# sourceMappingURL=CompletionItemsAssertion.js.map