"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hover = void 0;
const vitest_1 = require("vitest");
const hover = async function (provider, context, expected) {
    const { isNot, equals, utils } = this;
    const hoverContext = asHoverContext(context);
    const { source, relativePath } = hoverContext;
    const { documentManager } = provider;
    const cursorPosition = source.indexOf('█');
    if (cursorPosition === -1) {
        return {
            pass: false,
            message: () => 'Expected to find "█" in context string to represent cursor position',
        };
    }
    const textDocumentUri = `file:///${relativePath}`;
    documentManager.open(textDocumentUri, source.replace(/█/g, ''), 0);
    const textDocument = documentManager.get(textDocumentUri).textDocument;
    const params = {
        position: textDocument.positionAt(cursorPosition),
        textDocument: {
            uri: textDocumentUri,
        },
    };
    const result = await provider.hover(params);
    const isExpectingNull = expected === null;
    if (isExpectingNull) {
        return {
            pass: result === expected,
            message: () => `expected hover to ${isNot ? 'not ' : ''}be null`,
            actual: result,
            expected: expected,
        };
    }
    return {
        pass: equals(result, vitest_1.expect.objectContaining({
            contents: {
                kind: 'markdown',
                value: expected,
            },
        })),
        message: () => `expected hover to${isNot ? ' not' : ''} match value ${utils.printExpected(expected)}\ncontext:\n${context}`,
        actual: result === null ? result : result.contents.value,
        expected: expected,
    };
};
exports.hover = hover;
function asHoverContext(context) {
    if (typeof context === 'string')
        return { source: context, relativePath: 'file.liquid' };
    return context;
}
//# sourceMappingURL=HoverAssertion.js.map